@@ -4,7 +4,7 @@
 # This file is subject to the MIT License (see the LICENSE file).
 
 __copyright__ = '2010-2012, Silas Sewell'
-__version__ = '0.4.6'
+__version__ = '0.4.7'
 
 import collections
 import copy
@@ -358,7 +358,7 @@ class find(object):
         for root_path, dir_list, file_list in os.walk(self.path, topdown=self.top_down):
             if self.no_peek and not self.top_down:
                 for d in dir_list:
-                    p = path(root=self.path, name=d)
+                    p = path(root=root_path, name=d)
                     if self._match(p):
                         yield p
             else:
@@ -747,6 +747,8 @@ class path(unicode):
       True
       >>> p
       /tmp
+      >>> p.join('foo')
+      /tmp/foo
       >>> p.stat.user.name
       root
     """
@@ -766,6 +768,9 @@ class path(unicode):
             obj._stat = stat
         return obj
 
+    def join(self, *args, **kwargs):
+        return path(os.path.join(self, *args, **kwargs))
+
 def rm(path, recursive=False):
     """Delete a specified file or directory. This function does not recursively
     delete by default.
